@@ -89,8 +89,12 @@ def run_server (config):
     logging.info('Neutron Beam Stopped')
     
   finally:
-    raise
-  
+    try:
+      raise
+    
+    except:
+      pass
+    
 def default_config ():
   return {
     'daemon': True,
@@ -108,8 +112,9 @@ def generate_key ():
   ).rstrip('==')
   
 def send_kill (pid):
+  os.kill(pid, signal.SIGTERM)
+  
   while is_running(pid):
-    os.kill(pid, signal.SIGTERM)
     time.sleep(1)
     
 def is_running (pid):
